import express from "express";
import { addLoginDetails, login } from "../services/admin.service.js";
import { APIError } from "rest-api-errors";
import {
  addCurrency,
  getAgencyRates,
  getCurrencies,
  updateCurrency,
} from "../controllers/adminController.js";

const router = express();

router.get("/login", async (req, res, next) => {
  try {
    const { username, password } = req?.query;
    if (!username) {
      throw new APIError(400, "400", "Please pass username.");
    }
    if (!password) {
      throw new APIError(400, "400", "Please pass password.");
    }
    const data = await login(username, password);

    await addLoginDetails(data);
    res.json({
      success: true,
      data,
    });
  } catch (error) {
    next(error);
  }
});

router.post("/getAgencyRates", getAgencyRates);
router.get("/getCurrencies/:authorizationToken/:username", getCurrencies);
router.post("/addCurrency/:authorizationToken/:username", addCurrency);
router.patch("/updateCurrency/:authorizationToken/:username", updateCurrency);



export default router;
