import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ViewComplianceListService } from '../services/view-compliance-list.service';
import { HttpClient } from '@angular/common/http';
import { Router } from '@angular/router';
import { getCacheData } from '../utils/helper';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-complaince-view-list-approve',
  templateUrl: './complaince-view-list-approve.component.html',
  styleUrls: ['./complaince-view-list-approve.component.css'],
})
export class ComplainceViewListApproveComponent implements OnInit {
  selectedRejectionReason: string;
  showDetails: boolean = false; // Property to control the visibility
  showCust: boolean = false; // Property to control the visibility
  transaction: any;
  CustomerCompliance: any;
  userId: any = 1001005;
  remark: string = '';
  Approveremark: string = '';
  transactionNumber: any;
  isMGTxn: any = 'eer';
  isMTOSuccess: any = 345;
  rejectReason: any = 'er';
  orgMsgID: any = 1;
  transactionRemarkHold: any;
  BeneficiaryRemarkHold: any;
  CustomerRemarkHold: any;
  CustomerRejectionReason: any;
  BeneficiaryRejectionReason: any;
  transactionRemark: any;
  // new
  rejectionReasons: any[] = []; // Initialize as an empty array to store rejection reasons

  showDetailsTable: boolean = false;
  details: any[] = [];
  detailType: string;
  isLoading: boolean = false; // Loader flag
  showPrintButton: boolean = false;
  constructor(
    private route: ActivatedRoute,
    private viewComplianceListService: ViewComplianceListService,
    private router: Router,
    private toastrSvc: ToastrService
  ) {}

  showCustomerDetails() {
    if (this.transactionNumber) {
      this.showDetails = false;
      this.showDetailsTable = false;
      this.viewComplianceListService
        .getComplianceShowDetailWithSearchType(this.transactionNumber, 'REM')
        .subscribe(
          (response: any) => {
            console.log('Customer Details Response:', response);
            this.details = response as any[];
            this.detailType = 'Customer';
            this.showCust = true;
            this.showDetailsTable = true;
          },
          (error) => {
            console.error('Error fetching customer details:', error);
          }
        );
    }
  }

  showBeneficiaryDetails() {
    if (this.transactionNumber) {
      this.showCust = false;
      this.showDetailsTable = false;
      this.viewComplianceListService
        .getComplianceShowDetailWithSearchType(this.transactionNumber, 'BEN')
        .subscribe(
          (response: any) => {
            console.log('Beneficiary Details Response:', response);
            this.details = response as any[];
            this.detailType = 'Beneficiary';
            this.showDetails = true;
            this.showDetailsTable = true;
          },
          (error) => {
            console.error('Error fetching beneficiary details:', error);
          }
        );
    }
  }

  ngOnInit() {
    this.transactionNumber = this.route.snapshot.paramMap.get('id');

    // Fetch the rejection reasons
    this.viewComplianceListService.rejectionReason().subscribe(
      (response: any) => {
        this.rejectionReasons = response.filter(
          (reason: any) => reason.IsActive
        );

        console.log('Rejection reasons:', this.rejectionReasons);
      },
      (error) => {
        console.error('Error fetching rejection reasons:', error);
      }
    );
    this.viewComplianceListService
      .getTransactionPrefix(this.transactionNumber)
      .subscribe(
        (response: any) => {
          if (response && response == 'Failed') {
            // assuming the response contains a `successful` flag

            this.loadComplianceList();
            this.loadRequiredDetail();
          } else {
            this.loadComplianceListBindData();
            this.loadRequiredDetail();
          }
        },
        (error) => {
          console.error('Error fetching transaction prefix:', error);
          // You may choose to handle errors specifically here, maybe with an alert or alternative logic.
        }
      );
  }

  loadRequiredDetail() {
    if (this.transactionNumber) {
      this.viewComplianceListService
        .getRequiredDetail(this.transactionNumber)
        .subscribe(
          (response) => {
            this.CustomerCompliance = response[0];
          },
          (error) => {
            console.error(error);
          }
        );
    }
  }

  loadComplianceList() {
    if (this.transactionNumber) {
      this.viewComplianceListService
        .getBindWithoutSbiTransactionNumber(this.transactionNumber)
        .subscribe(
          (response) => {
            this.transaction = response[0];
          },
          (error) => {
            console.error(error);
          }
        );
    }
  }
  loadComplianceListBindData() {
    if (this.transactionNumber) {
      this.viewComplianceListService
        .getBindData(this.transactionNumber)
        .subscribe(
          (response) => {
            this.transaction = response[0];
          },
          (error) => {
            console.error(error);
          }
        );
    }
  }
  onHold() {
    if (!this.transactionRemarkHold) {
      alert('Please enter a remark before placing the compliance hold.');
      return;
    }
    this.viewComplianceListService
      .updateComplianceOnHold(
        this.transactionNumber,
        this.transactionRemarkHold
        // this.userId
      )
      .subscribe(
        (response) => {
          console.log(
            'Compliance hold action completed successfully:',
            response
          );
          this.router.navigate(['/panel/view-compliance-list']);
          // alert(response);
          // this.toastrSvc.success(response)
          this.toastrSvc.success(response.toString());

          this.transactionRemarkHold = '';
        },
        (error) => {
          console.error('Error putting compliance on hold:', error);
          let errorMessage =
            'An error occurred while putting compliance on hold. Please try again later.';
          if (error && error.error && error.error.message) {
            errorMessage = error.error.message;
          }
          // alert(errorMessage);
          this.toastrSvc.error(errorMessage);

          this.transactionRemarkHold = '';
        }
      );
  }

  onApprove() {
    if (!this.transactionRemark) {
      alert('Please enter a remark before approving compliance.');
      return;
    }

    this.viewComplianceListService
      .approveCompliance(this.transactionNumber, this.transactionRemark)
      .subscribe(
        (response) => {
          console.log('Compliance approved successfully:', response);
          this.router.navigate(['/panel/view-compliance-list']);
          // alert(response);
          // this.toastrSvc.success(response)
          this.toastrSvc.success(response.toString());

          this.transactionRemark = '';
        },
        (error) => {
          console.error('Error approving compliance:', error);
          // alert(error?.error?.message);
          this.toastrSvc.error(error?.error?.message);

          this.transactionRemark = '';
        }
      );
  }

  onReject() {
    if (!this.transactionRemark) {
      return alert('Please enter a remark before Reject compliance.');
    }
    this.isLoading = true;
    const payload = {
      TransactionNumber: this.transactionNumber,
      UserID: getCacheData('G_UserID'),
      IsMGTxn: this.CustomerCompliance.IsMGTxn,
      IsMTOSuccess: this.CustomerCompliance.IsMTOSuccess,
      RejectReason: 'Other',
      Remark: this.transactionRemark,
      OrgMsgID: '',
    };

    this.viewComplianceListService.transactionReject(payload).subscribe(
      (response) => {
        // alert(response);
        //  this.toastrSvc.success(response)
        this.toastrSvc.success(response.toString());

        this.isLoading = false;
        this.transactionRemark = '';
      },
      (error) => {
        console.log(error);
        // alert(error.error.message);
        this.toastrSvc.error(error.error.message);

        this.isLoading = false;
        this.transactionRemark = '';
      }
    );
  }

  CustomeronReject() {
    // if (!this.CustomerRemarkHold) {
    //   return alert('Please enter a remark before Reject compliance.');
    // }
    this.isLoading = true;
    const payload = {
      TransactionNumber: this.transactionNumber,
      UserID: getCacheData('G_UserID'),
      IsMGTxn: this.CustomerCompliance.IsMGTxn,
      IsMTOSuccess: this.CustomerCompliance.IsMTOSuccess,
      RejectReason: this.CustomerRejectionReason,
      Remark: this.CustomerRemarkHold,
      OrgMsgID: this.CustomerCompliance.OrgMsgID,
      CustomerBeneficiaryNo: this.CustomerCompliance.CustNumber,
    };

    this.viewComplianceListService.customerReject(payload).subscribe(
      (response) => {
        // alert(response);
        this.toastrSvc.success(response.toString());

        this.isLoading = false;
        this.CustomerRemarkHold = '';
        this.loadComplianceList();
        this.loadRequiredDetail();
      },
      (error) => {
        console.log(error);
        // alert(error.error.message);
        this.toastrSvc.error(error.error.message);
        this.isLoading = false;
        this.CustomerRemarkHold = '';
      }
    );
  }

  BeneficiarReject() {
    // if (!this.BeneficiaryRemarkHold) {
    //   return alert('Please enter a remark before Reject compliance.');
    // }
    this.isLoading = true;
    const payload = {
      TransactionNumber: this.transactionNumber,
      UserID: getCacheData('G_UserID'),
      IsMGTxn: this.CustomerCompliance.IsMGTxn,
      IsMTOSuccess: this.CustomerCompliance.IsMTOSuccess,
      RejectReason: this.BeneficiaryRejectionReason,
      Remark: this.BeneficiaryRemarkHold,
      OrgMsgID: this.CustomerCompliance.OrgMsgID,
      CustomerBeneficiaryNo: this.CustomerCompliance.BenNo,
    };

    this.viewComplianceListService.beneficiaryReject(payload).subscribe(
      (response) => {
        // alert(response);
        this.toastrSvc.success(response.toString());

        this.isLoading = false;
        this.BeneficiaryRemarkHold = '';
        this.loadComplianceList();
        this.loadRequiredDetail();
      },
      (error) => {
        console.log(error);
        // alert(error.error.message);
        this.toastrSvc.error(error.error.message);

        this.isLoading = false;
        this.BeneficiaryRemarkHold = '';
      }
    );
  }

  BeneficiaryApprove() {
    // if (!this.BeneficiaryRemarkHold) {
    //   return alert('Please enter a remark before Approve Beneficiary.');
    // }
    this.isLoading = true;
    const payload = {
      CustStatus: this.CustomerCompliance.ISCustInCompliance,
      CustApprove: this.CustomerCompliance.ISCustApprove,
      TransactionNumber: this.transactionNumber,
      Remark: this.BeneficiaryRemarkHold,
      UserID: getCacheData('G_UserID'),
      CustomerBeneficiaryNo: this.CustomerCompliance.BenNo,
      BENStatus: this.CustomerCompliance.IsBenInCompliance,
      BENApprove: this.CustomerCompliance.IsBenApprove,
      IsMGTxn: this.CustomerCompliance.IsMGTxn,
      TxnExpired: 'N',
      TxnTime: this.CustomerCompliance.TxnTime,
      MGWaitMin: this.CustomerCompliance.MGWaitMin,
      OrgMsgID: this.CustomerCompliance.OrgMsgID,
      IsMTOSuccess: this.CustomerCompliance.IsMTOSuccess,
      RejectReason: this.BeneficiaryRejectionReason,
    };

    this.viewComplianceListService.beneficiaryApprove(payload).subscribe(
      (response) => {
        // alert(response);
        this.toastrSvc.success(response.toString());

        this.isLoading = false;
        this.BeneficiaryRemarkHold = '';
        this.loadComplianceList();
        this.loadRequiredDetail();
      },
      (error) => {
        console.log(error);
        // alert(error.error.message);
        this.toastrSvc.error(error.error.message);

        this.isLoading = false;
        this.BeneficiaryRemarkHold = '';
      }
    );
  }

  CustomerApprove() {
    // if (!this.CustomerRemarkHold) {
    //   return alert('Please enter a remark before Approve Customer.');
    // }
    this.isLoading = true;

    this.viewComplianceListService
      .customerApprove(
        this.transactionNumber,
        this.CustomerRemarkHold,
        this.CustomerCompliance.CustNumber
      )
      .subscribe(
        (response) => {
          // alert(response);
          this.toastrSvc.success(response.toString());

          this.isLoading = false;
          this.CustomerRemarkHold = '';
          this.loadComplianceList();
          this.loadRequiredDetail();
        },
        (error) => {
          console.log(error);
          // alert(error.error.message);
          this.toastrSvc.error(error.error.message);

          this.isLoading = false;
          this.CustomerRemarkHold = '';
        }
      );
  }

  onPrint() {
    this.isLoading = true; // Show loader
    // Simulate loading time
    setTimeout(() => {
      this.isLoading = false; // Hide loader
      this.showPrintButton = true; // Show the print button
    }, 2000); // Adjust the timeout as needed
  }

  printDocument() {
    // Implement your print logic here
    window.print();
    this.showPrintButton = false; // Hide the print button after printing
  }
  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  showBeneficiaryDetailsTable() {
    if (this.transactionNumber) {
      this.showCust = false;
      this.showDetailsTable = false;
      this.viewComplianceListService
        .getComplianceShowDetail(this.transactionNumber, 'BEN')
        .subscribe(
          (response: any) => {
            console.log('Customer Details Response:', response);
            this.details = response as any[];
            this.detailType = 'Beneficiary';
            this.showDetails = true;
            this.showDetailsTable = true;
          },
          (error) => {
            console.error('Error fetching customer details:', error);
          }
        );
    }
  }

  navigateBack() {
    // Replace '/complaince-hold-transaction-process' with the desired URL
    this.router.navigateByUrl('/panel/view-compliance-list');
  }
}
