import { Component, OnInit } from '@angular/core';
import * as XLSX from 'xlsx';
import { ComplianceUploadReportService } from '../services/compliance-upload-report.service';

@Component({
  selector: 'app-compliance-upload-report',
  templateUrl: './compliance-upload-report.component.html',
  styleUrls: ['./compliance-upload-report.component.css'],
})
export class ComplianceUploadReportComponent implements OnInit {
  selectedFileFormat: string = 'excel';
  selectedFileType: string ='FOFDBOF'; 
  records: any[] = [];
  isLoading: boolean = false;
  currentPage = 1; // Current page number
  itemsPerPage = 15; // Number of items per page

  constructor(
    private complianceUploadReportService: ComplianceUploadReportService
  ) {}

  ngOnInit(): void {
    this.loadRecords();
  }

  loadRecords() {
    this.isLoading = true;

    this.complianceUploadReportService
      .getAllComplianceUploadReportRecords()
      .subscribe({
        next: (res: any) => {
          if (res?.length == 0) {
            this.records = [];
            alert('No data found.');
            return;
          }
          this.records = res;
          this.records.forEach((record) => {
            // Allow only certain characters in AdditionalInfo field
            record.AdditionalInfo = record.AdditionalInfo.replace(
              /[^a-zA-Z0-9 ,;.:()/\\]/g,
              ''
            );
            record.expanded = false;
          });
          this.isLoading = false;
        },
        error: (err) => {
          console.error('Error fetching compliance upload records:', err);
          this.isLoading = false;
        },
      });
  }

  toggleExpansion(record: any): void {
    record.expanded = !record.expanded;
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  exportToExcel() {
    /* generate worksheet */
    const ws: XLSX.WorkSheet = XLSX.utils.json_to_sheet(this.records);

    /* generate workbook and add the worksheet */
    const wb: XLSX.WorkBook = XLSX.utils.book_new();
    XLSX.utils.book_append_sheet(wb, ws, 'Sheet1');

    /* save to file */
    const fileName = `Compliance_Report_${Date.now()}.${
      this.selectedFileFormat === 'excel' ? 'xlsx' : 'csv'
    }`;
    XLSX.writeFile(wb, fileName);
  }

  onFileTypeChange(event: any) {
    // Update the selectedFileFormat variable with the selected value
    this.selectedFileType = event.target.value;
    // Optionally, perform additional actions
    console.log('Selected File Format:', this.selectedFileType);
  }

  filter(){
    console.log(this.selectedFileType)
    this.isLoading = true;
    this.complianceUploadReportService
      .getAllComplianceUploadReportRecords(this.selectedFileType)
      .subscribe({
        next: (res: any) => {
          if (res?.length == 0) {
            this.records = [];
            alert('No data found.');
            this.isLoading = false;
            return;
          }
          this.records = res;
          this.records.forEach((record) => {
            // Allow only certain characters in AdditionalInfo field
            record.AdditionalInfo = record.AdditionalInfo.replace(
              /[^a-zA-Z0-9 ,;.:()/\\]/g,
              ''
            );
            record.expanded = false;
          });
          this.isLoading = false;
        },
        error: (err) => {
          console.error('Error fetching compliance upload records:', err);
          this.isLoading = false;
        },
      });
  }
  firstPage() {
    this.currentPage = 1;
  }

  prevPage() {
    if (this.currentPage > 1) {
      this.currentPage--;
    }
  }

  nextPage() {
    const totalPages = this.getTotalPages();
    if (this.currentPage < totalPages) {
      this.currentPage++;
    }
  }

  lastPage() {
    const totalPages = this.getTotalPages();
    this.currentPage = totalPages;
  }

  // Calculate total number of pages based on items per page
  getTotalPages() {
    return Math.ceil(this.records.length / this.itemsPerPage);
  }
  // Calculate start index for current page
  getStartIndex() {
    return (this.currentPage - 1) * this.itemsPerPage;
  }

  // Calculate end index for current page
  getEndIndex() {
    return this.getStartIndex() + this.itemsPerPage;
  }

  // Get data for the current page
  getDataForCurrentPage(): any[] {
    return this.records.slice(this.getStartIndex(), this.getEndIndex());
  }


  
}