import { Component } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { StopPaymentService } from '../services/stop-payment.service';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-edit-stop-payment',
  templateUrl: './edit-stop-payment.component.html',
  styleUrls: ['./edit-stop-payment.component.css'],
})
export class EditStopPaymentComponent {
  statusList: any = [];
  selectedStatus: any;
  details: any = {};
  transactionNo: any = '';
  branchId: any = '';
  appID: any = '';
  refNo: any = '';
  remark: any = '';

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private stopPaymentSvc: StopPaymentService,
    private toastrSvc: ToastrService
  ) { }

  ngOnInit(): void {
    // Accessing path parameters
    this.branchId = this.route.snapshot.paramMap.get('Branch');
    this.appID = this.route.snapshot.paramMap.get('AppID');
    this.refNo = this.route.snapshot.paramMap.get('RefNo');
    this.transactionNo = this.route.snapshot.paramMap.get('trnNo');
    this.getStatusList();
    if (this.branchId && this.appID && this.refNo) {
      this.displayDetails(this.appID, this.branchId, this.refNo);
    }
  }

  getStatusList() {
    this.stopPaymentSvc.getStatusList().subscribe({
      next: (res: any) => {
        this.statusList = res;
        this.statusList = [
          ...res, // Spread the existing items
          { TrStatusID: 27, Tr_Status_Name: 'Process For Paid' }, // New object to add
        ];
        this.selectedStatus = res?.[0]?.TrStatusID;
      },
      error: () => {
        this.statusList = [];
      },
      complete: () => { },
    });
  }

  displayDetails(appId: any = '', branchId: any = '', refNo: any = '') {
    this.stopPaymentSvc.displayDetails(appId, branchId, refNo).subscribe({
      next: (res: any) => {
        this.details = res?.[0];
      },
      error: () => { },
      complete: () => { },
    });
  }

  updateStatus() {
    if (!this.remark) {
      alert('Please Enter Remark.');
      return;
    }
    if (this.appID && this.branchId) {
      const payload = {
        SRTRNo: this.transactionNo,
        TrStatusID: this.selectedStatus,
        EnteredBy: 'none',
        _Remark: this.remark,
        _Branch: this.branchId,
        _AppID: this.appID,
        _RefNo: this.refNo,
      };
      this.stopPaymentSvc.updateStatus(payload).subscribe({
        next: (res: any) => {
          if (res) {
            // alert('Transaction stop successfully.');
            this.toastrSvc.success('Transaction stop successfully.');
            this.router.navigate(['/panel/stop-payment']);
          }
        },
        error: (err) => {
          this.toastrSvc.error(err?.error?.message);
          // this.router.navigate(['/panel/stop-payment']);
        },
        complete: () => { },
      });
    }
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
