import { Component } from '@angular/core';
import { GlobalTransactionLimitService } from '../services/global-transaction-limit.service';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-global-transaction-limit',
  templateUrl: './global-transaction-limit.component.html',
  styleUrls: ['./global-transaction-limit.component.css'],
})
export class GlobalTransactionLimitComponent {
  globalTransactionLimitList: any = [];
  private _transactionLimit: number = 0.00;
  private _transactionLimitBank: number = 0.00;
  isLoading: boolean = false;

  constructor(private globalTransactionSvc: GlobalTransactionLimitService,
    private toastrSvc: ToastrService


  ) { }

  ngOnInit(): void {
    this.getGlobalTransactionList();
  }
  get transactionLimit(): string {
    return this._transactionLimit.toFixed(3);
  }

  set transactionLimit(value: string) {
    this._transactionLimit = parseFloat(value);
  }

  get transactionLimitBank(): string {
    return this._transactionLimitBank.toFixed(3);
  }

  set transactionLimitBank(value: string) {
    this._transactionLimitBank = parseFloat(value);
  }
  getGlobalTransactionList() {
    this.isLoading = true;

    this.globalTransactionSvc.getGlobalTransactionList().subscribe({
      next: (res: any) => {
        this.globalTransactionLimitList =
          res?.GlobalPerTranMonthlyThresholdLimits;
        this._transactionLimit = parseFloat(res?.TransactionLimitInUSD) || 0.00;
        this._transactionLimitBank = parseFloat(res?.TransactionLimitInUSD_Bank) || 0.00;
      },
      error: (err) => {
        this.globalTransactionLimitList = [];
        this.isLoading = false;
      },
      complete: () => {
        this.isLoading = false;
      },
    });
  }

  updateGlobalLimit() {
    if (!this.transactionLimit && !this.transactionLimitBank) {
      alert('Please Fill Cash & Bank Fields.');
      return;
    }

    if (!this.transactionLimit) {
      alert('Please Enter Cash Amount.');
      return;
    }

    if (!this.transactionLimitBank) {
      alert('Please Enter Bank Amount.');
      return;
    }
    this.globalTransactionSvc
      .updateGlobalLimit('', this.transactionLimit, this.transactionLimitBank)
      .subscribe({
        next: (res: any) => {
          this.getGlobalTransactionList();
          // alert('Global Transaction Limit Updated successfully.');
          this.toastrSvc.success(res)
        },
        error: (err) => {
          // alert(err?.error?.Message);
          this.toastrSvc.error(err?.error?.Message)
        },
        complete: () => { },
      });
  }

  updateSegment() {
    const payload = {
      SegPlatinumPerTranLimit:
        this.globalTransactionLimitList[0].GMPSL_Platinum_PerTran_Limit,
      SegPlatinumMonthlyLimit:
        this.globalTransactionLimitList[0].GMPSL_Platinum_Monthly_Limit,
      chkPlatinum_IsActive:
        this.globalTransactionLimitList[0].GMPSL_Platinum_IsActive,
      SegGoldPerTranLimit:
        this.globalTransactionLimitList[0].GMPSL_Gold_PerTran_Limit,
      SegGoldMonthlyLimit:
        this.globalTransactionLimitList[0].GMPSL_Gold_Monthly_Limit,
      chkGold_IsActive: this.globalTransactionLimitList[0].GMPSL_Gold_IsActive,
      SegSilverPerTranLimit:
        this.globalTransactionLimitList[0].GMPSL_Silver_PerTran_Limit,
      SegSilverMonthlyLimit:
        this.globalTransactionLimitList[0].GMPSL_Silver_Monthly_Limit,
      chkSilver_IsActive:
        this.globalTransactionLimitList[0].GMPSL_Silver_IsActive,
      SegStaffPerTranLimit:
        this.globalTransactionLimitList[0].GMPSL_Staff_PerTran_Limit,
      SegStaffMonthlyLimit:
        this.globalTransactionLimitList[0].GMPSL_Staff_Monthly_Limit,
      chkStaff_IsActive:
        this.globalTransactionLimitList[0].GMPSL_Staff_IsActive,
      SegEasyPayPerTranLimit:
        this.globalTransactionLimitList[0].GMPSL_EasyPay_PerTran_Limit,
      SegEasyPayMonthlyLimit:
        this.globalTransactionLimitList[0].GMPSL_EasyPay_Monthly_Limit,
      chkEasyPay_IsActive:
        this.globalTransactionLimitList[0].GMPSL_EasyPay_IsActive,
      SegVMobilePerTranLimit:
        this.globalTransactionLimitList[0].GMPSL_VMobile_PerTran_Limit,
      SegVMobileMonthlyLimit:
        this.globalTransactionLimitList[0].GMPSL_VMobile_Monthly_Limit,
      chkVMobile_IsActive:
        this.globalTransactionLimitList[0].GMPSL_VMobile_IsActive,
      SegPrivatePerTranLimit:
        this.globalTransactionLimitList[0].GMPSL_Private_PerTran_Limit,
      SegPrivateMonthlyLimit:
        this.globalTransactionLimitList[0].GMPSL_Private_Monthly_Limit,
      chkPrivate_IsActive:
        this.globalTransactionLimitList[0].GMPSL_Private_IsActive,
      UserID: 0,
    };
    this.globalTransactionSvc.updateSegmentLimit(payload).subscribe({
      next: (res: any) => {
        this.getGlobalTransactionList();
        // alert(
        //   'Per Transaction and Monthy Threshold Transaction Limit Updated successfully.'
        // );
        this.toastrSvc.success(res)

      },
      error: (err) => {
        this.toastrSvc.error(err?.error?.Message)
      },
      complete: () => { },
    });
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }


  formatToThreeDecimals(value: string | number): string {
    let num = parseFloat(value as string);
    if (isNaN(num)) return '0.000';
    return num.toFixed(3);
  }

  // This function updates the model on user input
  formatOnInput(value: string | number): string {
    let num = parseFloat(value as string);
    if (isNaN(num)) return '0.000';
    return num.toFixed(3);
  }


  validateGoldLimits(item: any): void {
    // Ensure both values are converted to numbers to compare properly
    let perTransactionLimit = parseFloat(item.GMPSL_Gold_PerTran_Limit);
    let monthlyLimit = parseFloat(item.GMPSL_Gold_Monthly_Limit);

    if (isNaN(perTransactionLimit) || isNaN(monthlyLimit)) {
      alert('Please enter valid numbers for comparison.');
      return;
    }

    // Check if the monthly limit is less than the per transaction limit
    if (monthlyLimit < perTransactionLimit) {
      alert('Gold Monthly Limit must be greater than or equal to Per Transaction Threshold Limit.');
      // Optionally reset the monthly limit to the per transaction limit
      item.GMPSL_Gold_Monthly_Limit = item.GMPSL_Gold_PerTran_Limit;
    }
  }


}
