import { Component, TemplateRef, ViewChild } from '@angular/core';
import { RaCtaHoldTransactionService } from '../services/ra-cta-hold-transaction.service';
import { AuthService } from '../services/auth.service';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { ViewTransactionStatusForAgentService } from '../view-transaction-status-for-agent.service';
import { getCacheData } from '../utils/helper';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-ra-cta-hold-transaction',
  templateUrl: './ra-cta-hold-transaction.component.html',
  styleUrls: ['./ra-cta-hold-transaction.component.css'],
})
export class RaCtaHoldTransactionComponent {
  @ViewChild('viewTransactionReceipt') viewTransactionReceiptModal;
  bsTransactionReceiptModalRef: BsModalRef;

  isLoading: boolean = false;
  countryList: any = [];
  selectedCountry: any;
  agentList: any = [];
  selectedAgent: any = '0';
  fromDate: any = '';
  toDate: any = '';
  allRecord: any = [];
  receiptData: any = {};
  totalLCAmount: number = 0;
  totalUSDAmount: number = 0;
  selectAllChecked: boolean = false;
  isReleaseBtn: boolean = false;

  constructor(
    private raCTAService: RaCtaHoldTransactionService,
    private authSvc: AuthService,
    private ViewTransactionStatusForAgentSvc: ViewTransactionStatusForAgentService,
    private modalService: BsModalService,
    private toastrSvc: ToastrService
  ) {}

  ngOnInit(): void {
    this.getCountryList();
    this.fromDate = this.authSvc.getTodayDate();
    this.toDate = this.authSvc.getTodayDate();
  }

  getCountryList() {
    this.raCTAService.getCountry().subscribe({
      next: (res: any) => {
        this.countryList = res;
        this.selectedCountry = res?.[0]?.CountryID;
        this.getAgentList(res?.[0]?.CountryID);
      },
      error: (err) => {
        this.countryList = [];
      },
      complete: () => {},
    });
  }

  onCountryChange(countryId) {
    if (countryId != '0') {
      this.getAgentList(countryId);
    }
  }

  getAgentList(countryId: any = 0) {
    this.raCTAService.getAgents(countryId).subscribe({
      next: (res: any) => {
        this.agentList = res;
        this.selectedAgent = res?.[0]?.AgentID;
      },
      error: (err) => {
        this.agentList = [];
      },
      complete: () => {},
    });
  }

  displayByDate() {
    if (!this.fromDate || !this.toDate) {
      alert('Please Select From & To Dates.');
      return;
    }

    if (!this.selectedAgent) {
      alert('Please Select Agent.');
      return;
    }
    this.isLoading = true;
    this.raCTAService
      .getAllRecord(this.fromDate, this.toDate, this.selectedAgent)
      .subscribe({
        next: (res: any) => {
          if (res?.length == 0) {
            alert('No data found.');
            return;
          }
          this.isReleaseBtn = false;
          this.allRecord = res;
          this.allRecord = this.allRecord.map((record) => ({
            ...record,
            selected: false,
          }));
          for (let index = 0; index < this.allRecord.length; index++) {
            const element = this.allRecord[index];
            if (element?.LCAmount !== null && element?.LCAmount !== undefined) {
              element.LCAmount = this.formatWithTwoDecimalPlaces(
                element.LCAmount
              );
            }
            if (
              element?.LCAmountUSD !== null &&
              element?.LCAmountUSD !== undefined
            ) {
              element.LCAmountUSD = this.formatWithTwoDecimalPlaces(
                element.LCAmountUSD
              );
            }
          }
          this.isLoading = false;
        },
        error: (err) => {
          this.allRecord = [];
          this.isLoading = false;
        },
        complete: () => {
          this.isLoading = false;
        },
      });
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  getTransactionNumberDetail(item) {
    const trnNo = item?.SRTRNo;
    this.ViewTransactionStatusForAgentSvc.getTransactionReport(trnNo).subscribe(
      (res: any) => {
        if (res?.[0]?.IsDuplicate == true) {
          alert('No data found.');
          return;
        }
        this.receiptData = res?.[0];
        this.openTransactionReceiptModal(this.viewTransactionReceiptModal);
      }
    );
  }

  openTransactionReceiptModal(template: TemplateRef<any>) {
    this.bsTransactionReceiptModalRef = this.modalService.show(template, {
      class: 'modal-lg',
    });
  }

  selectAll(event: any) {
    const checked = event.target.checked;
    this.selectAllChecked = checked;
    this.allRecord.forEach((record) => (record.selected = checked));
    this.updateTotals();
  }

  updateTotals() {
    this.totalLCAmount = this.allRecord
      .filter((record) => record.selected)
      .reduce((sum, record) => sum + parseFloat(record.LCAmount || '0'), 0);
    this.totalUSDAmount = this.allRecord
      .filter((record) => record.selected)
      .reduce((sum, record) => sum + parseFloat(record.LCAmountUSD || '0'), 0);
  }

  formatWithTwoDecimalPlaces(value: number | string): string {
    if (value === null || value === undefined) {
      return '';
    }

    const stringValue = value.toString();
    const [integerPart, fractionalPart] = stringValue.split('.');

    if (fractionalPart) {
      // Pad with zeros to ensure 2 decimal places
      return `${integerPart}.${fractionalPart.padEnd(2, '0').slice(0, 2)}`;
    } else {
      // If no decimal places, add 2 zeros
      return `${integerPart}.00`;
    }
  }

  preview() {
    const selectedRecords = this.allRecord.filter((record) => record.selected);
    if (selectedRecords?.length == 0) {
      alert('Please Select Transaction for Preview.');
      return;
    }
    const payload = selectedRecords.map((record) => ({
      IsChk: record.selected,
      TransactionNumber: record.SRTRNo, // assuming SRTRNo is the transaction number
      UserID: getCacheData('G_UserID'), // assuming UserID is present in your record
    }));
    this.raCTAService
      .preview(this.fromDate, this.toDate, this.selectedAgent, payload)
      .subscribe({
        next: (res: any) => {
          if (res) {
            this.allRecord = res;
            this.isReleaseBtn = true;
            this.allRecord = this.allRecord.map((record) => ({
              ...record,
              selected: true,
            }));
            this.selectAllChecked = true;
            this.updateTotals();
            for (let index = 0; index < this.allRecord.length; index++) {
              const element = this.allRecord[index];
              if (
                element?.LCAmount !== null &&
                element?.LCAmount !== undefined
              ) {
                element.LCAmount = this.formatWithTwoDecimalPlaces(
                  element.LCAmount
                );
              }
              if (
                element?.LCAmountUSD !== null &&
                element?.LCAmountUSD !== undefined
              ) {
                element.LCAmountUSD = this.formatWithTwoDecimalPlaces(
                  element.LCAmountUSD
                );
              }
            }
          }
        },
        error: (err) => {
          this.toastrSvc.error(err?.error?.message);
        },
        complete: () => {},
      });
  }

  batchApproved() {
    const selectedRecords = this.allRecord.filter((record) => record.selected);
    if (selectedRecords?.length == 0) {
      alert('Please Select Transaction for Release.');
      return;
    }
    const payload = selectedRecords.map((record) => ({
      IsChk: record.selected,
      TransactionNumber: record.SRTRNo, // assuming SRTRNo is the transaction number
      UserID: getCacheData('G_UserID'), // assuming UserID is present in your record
    }));
    this.raCTAService.batchApproved(payload).subscribe({
      next: (res: any) => {
        if (res) {
          // alert('Transactions has been approved');
          this.toastrSvc.success('Transactions has been approved.');
          this.displayByDate();
        }
      },
      error: (err) => {
        // alert(err?.error?.message);
        this.toastrSvc.error(err?.error?.message);
      },
      complete: () => {},
    });
  }
}
