import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { RegisteredCustommersDetailsService } from '../services/registered-custommers-details.service';
import * as XLSX from 'xlsx';
@Component({
  selector: 'app-registered-customers-details',
  templateUrl: './registered-customers-details.component.html',
  styleUrls: ['./registered-customers-details.component.css'],
})
export class RegisteredCustomersDetailsComponent implements OnInit {
  form: FormGroup;
  customerTypes: any[] = [];
  gridData: any[] = [];
  gridSummaryData: any[] = [];
  selectedReportType: string = '1';
  isLoading: boolean = false; // Loader state
  selectedFileFormat: string = '1';

  constructor(
    private fb: FormBuilder,
    private registeredCustomersService: RegisteredCustommersDetailsService
  ) {}

  ngOnInit(): void {
    const currentStartDate = new Date(new Date().toLocaleString("en-US", { timeZone: "Asia/Riyadh" })).toISOString().substring(0, 10);

    const currentEndDate = new Date(new Date().toLocaleString("en-US", { timeZone: "Asia/Riyadh" })).toISOString().substring(0, 10);

    this.form = this.fb.group({
      startDate: [currentStartDate, Validators.required],
      endDate: [currentEndDate, Validators.required],
      customerType: ['0', Validators.required],
    });

    this.getTypeList();
  }
  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  getTypeList(): void {
    this.registeredCustomersService.getTypeList().subscribe(
      (data: any[]) => {
        this.customerTypes = data;
      },
      (error) => {
        console.error('Error fetching customer types:', error);
      }
    );
  }

  onSubmit(): void {
    if (this.form.valid) {
      const { startDate, endDate, customerType } = this.form.value;
      if (this.selectedReportType == '2') {
       
        this.gridSummaryData = [];
        this.gridData = [];
        this.getSummaryFillGrid(startDate, endDate, customerType);
      } else if (this.selectedReportType == '1') {
        this.gridData = [];
        this.gridSummaryData = [];
        this.getDetailedFillGrid(startDate, endDate, customerType);
      }
    } else {
      this.form.markAllAsTouched();
    }
  }

  getSummaryFillGrid(startDate: any, endDate: any, customerType: any): void {
    this.registeredCustomersService
      .getFillGrid(this.selectedReportType, customerType, startDate, endDate)
      .subscribe(
        (data: any[]) => {
         

          if (data?.[0]?.RptCustomeReportGridDetailedResponse?.length) {
            this.gridSummaryData = data[0].RptCustomeReportGridDetailedResponse;
          } else {
            alert('No data found.');
          }
        },
        (error) => {
          console.error('Error fetching grid data:', error);
          alert(error.error.message)
        }
      );
  }

  getDetailedFillGrid(startDate: any, endDate: any, customerType: any): void {
    this.registeredCustomersService
      .getFillGrid(this.selectedReportType, customerType, startDate, endDate)
      .subscribe(
        (data: any[]) => {
          this.gridData = data?.[0]?.RptCustomeReportGridSummaryResponse;
          if (data?.[0]?.RptCustomeReportGridSummaryResponse?.length) {
            this.gridData = data[0].RptCustomeReportGridSummaryResponse;
          } else {
            alert('No data found.');
          }
        },
        (error) => {
          console.error('Error fetching grid data:', error);
          alert(error.error.message)
        }
      );
  }

  get startDate() {
    return this.form.get('startDate');
  }

  get endDate() {
    return this.form.get('endDate');
  }

  get customerType() {
    return this.form.get('customerType');
  }

  getTotal(field: string): number {
    return this.gridData.reduce((total, item) => total + item[field], 0);
  }

  
  exportToExcel(): void {
    const stringifiedData = this.gridSummaryData.map(item => {
      const stringifiedItem = {};
      for (const key in item) {
        if (item.hasOwnProperty(key)) {
          stringifiedItem[key] = item[key] !== null && item[key] !== undefined ? String(item[key]) : '';
        }
      }
      return stringifiedItem;
    });

    const ws: XLSX.WorkSheet = XLSX.utils.json_to_sheet(stringifiedData);
    const wb: XLSX.WorkBook = XLSX.utils.book_new();
    XLSX.utils.book_append_sheet(wb, ws, 'Sheet1');
    XLSX.writeFile(wb, 'SummaryData.xlsx');
  }
}
