import { Component, ElementRef, ViewChild } from '@angular/core';
import * as XLSX from 'xlsx';
import { SuspiciousTransactionReportService } from '../services/suspicious-transaction-report.service';

@Component({
  selector: 'app-suspicious-transaction-report',
  templateUrl: './suspicious-transaction-report.component.html',
  styleUrls: ['./suspicious-transaction-report.component.css'],
})
export class SuspiciousTransactionReportComponent {
  @ViewChild('suspiciousReportTable') suspiciousReportTable: ElementRef;

  transactionNo: any = '';
  fromDate: string = new Date(new Date().toLocaleString("en-US", {timeZone: "Asia/Riyadh"})).toISOString().substring(0, 10);
  toDate: string = new Date(new Date().toLocaleString("en-US", {timeZone: "Asia/Riyadh"})).toISOString().substring(0, 10);
  
  allSuspiciousTransactions: any = [];
  selectedFileFormat: any = '1';
  isLoading: boolean = false;

  constructor(
    private suspiciousTransactionSvc: SuspiciousTransactionReportService
  ) {}

  ngOnInit(): void {}

  filterByTransactioNo() {
    if (!this.transactionNo) {
      alert('Please Enter Transaction No!');
      return;
    }

    this.isLoading = true;
    this.suspiciousTransactionSvc
      .getDataByTransactionNo(this.transactionNo)
      .subscribe({
        next: (res: any) => {
          if (res?.length == 0) {
            this.allSuspiciousTransactions = [];
            alert('No data found.');
            return;
          }
          this.allSuspiciousTransactions = res;
          this.transformData();
        },
        error: (err) => {
          this.allSuspiciousTransactions = [];
          alert(err?.error?.message || 'Something went wrong');
          this.isLoading = false;
        },
        complete: () => {
          this.isLoading = false;
        },
      });
  }

  displayByDate() {
    if (!this.fromDate || !this.toDate) {
      alert('Please Select From & To Date!');
      return;
    }

    this.isLoading = true;
    this.suspiciousTransactionSvc
      .getFillGrid(this.fromDate, this.toDate)
      .subscribe({
        next: (res: any) => {
          if (res?.length == 0) {
            this.allSuspiciousTransactions = [];
            alert('No data found.');
            return;
          }
          this.allSuspiciousTransactions = res;
          this.transformData();
        },
        error: (err) => {
          this.allSuspiciousTransactions = [];
          alert(err?.error?.message || 'Something went wrong');
          this.isLoading = false;
        },
        complete: () => {
          this.isLoading = false;
        },
      });
  }

  exportToExcel() {
    /* generate worksheet */
    const ws: XLSX.WorkSheet = XLSX.utils.table_to_sheet(
      this.suspiciousReportTable.nativeElement
    );

    /* generate workbook and add the worksheet */
    const wb: XLSX.WorkBook = XLSX.utils.book_new();
    XLSX.utils.book_append_sheet(wb, ws, 'Sheet1');

    /* save to file */
    const fileName = `View_Suspicious_Transactions${Date.now()}.xlsx`;
    XLSX.writeFile(wb, fileName);
  }

  transformData() {
    this.allSuspiciousTransactions = this.allSuspiciousTransactions.map(
      (item) => {
        const newItem = {};
        for (const key in item) {
          if (item.hasOwnProperty(key)) {
            const newKey = key.replace(/^\*|(?<=,)\*|\*(?=,|$)|\s+/g, ''); // Remove asterisk and replace spaces with underscores
            newItem[newKey] = item[key];
          }
        }
        return newItem;
      }
    );
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
